package com.zipcodewilmington.phone;

import com.zipcodewilmington.exceptions.InvalidPhoneNumberFormatException;

import java.lang.reflect.Array;
import java.util.ArrayList;
import java.util.logging.Logger;

/**
 * Created by leon on 5/1/17.
 */
public final class PhoneNumberFactory {
    private static final Logger logger = Logger.getGlobal();

    private PhoneNumberFactory() {
        /** This constructor is private
         *  This class is uninstantiable */
    }

    /**
     * @param phoneNumberCount - number of PhoneNumber objects to instantiate
     * @return array of randomly generated PhoneNumber objects
     */ //TODO - Implement logic
    public static PhoneNumber[] createRandomPhoneNumberArray(int phoneNumberCount) {
        ArrayList<PhoneNumber> phone = new ArrayList();
        phone.add(createRandomPhoneNumber(phoneNumberCount));
        PhoneNumber [] number = (PhoneNumber[]) phone.toArray();


        return number;
    }

    /**
     * @return an instance of PhoneNumber with randomly generated phone number value
     */ //TODO - Implement logic
    public static PhoneNumber createRandomPhoneNumber(int numbers) {
        double number  = Math.floor(100+Math.random()*900);
         double number2 =  Math.floor(1000+Math.random()*9000);


        return createPhoneNumberSafely((int)number, (int)number, (int)number2);
    }


    /**
     * @param areaCode          - 3 digit code
     * @param centralOfficeCode - 3 digit code
     * @param phoneLineCode     - 4 digit code
     * @return a new phone number object
     */ //TODO - if input is valid, return respective PhoneNumber object, else return null
    public static PhoneNumber createPhoneNumberSafely(int areaCode, int centralOfficeCode, int phoneLineCode) {
        try {
            String phoneNumber = "(" + areaCode + ")-" + centralOfficeCode + "-" + phoneLineCode;
            return createPhoneNumber(phoneNumber);
        }catch (InvalidPhoneNumberFormatException e) {
            logger.finest("(###)-###-#### is not a valid phone number");
            e.printStackTrace();
        }

        return null;

    }

    /**
     * @param phoneNumberString - some String corresponding to a phone number whose format is `(###)-###-####`
     * @return a new phone number object
     * @throws InvalidPhoneNumberFormatException - thrown if phoneNumberString does not match acceptable format
     */ // TODO - Add throws statement to method signature
    public static PhoneNumber createPhoneNumber(String phoneNumberString) throws InvalidPhoneNumberFormatException {
        PhoneNumber number = new PhoneNumber(phoneNumberString);
        logger.finest("Attempting to create a new PhoneNumber object with a value of (###)-###-####");
        return number;
    }
}
